summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/effects.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/effects.cc')
-rw-r--r--crawl-ref/source/effects.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/effects.cc b/crawl-ref/source/effects.cc
index cb370633a8..dc7ed52ea4 100644
--- a/crawl-ref/source/effects.cc
+++ b/crawl-ref/source/effects.cc
@@ -2854,8 +2854,8 @@ void update_level(double elapsedTime)
mons_total++;
#endif
- // Monsters that are leaving the level often do so now.
- if (mons_is_leaving(mon) && turns > random2(40) + 21)
+ // Pacified monsters often leave the level now.
+ if (mons_is_pacified(mon) && turns > random2(40) + 21)
{
make_mons_leave_level(mon);
continue;